@@ -52,48 +52,103 @@
 #' ## ------------------------------------------------------------
 #' ## classification
 #' ## ------------------------------------------------------------
+#' ## -------- iris data
 #' 
 #' ## iris "Petal.Width" partial dependence plot
 #' ##
-#' # iris_rf <- rfsrc(Species ~., data = iris)
-#' # iris_prtl <- plot.variable(iris_rf, xvar.names = "Petal.Width",
+#' # rfsrc_iris <- rfsrc(Species ~., data = iris)
+#' # partial_iris <- plot.variable(rfsrc_iris, xvar.names = "Petal.Width",
 #' #                            partial=TRUE)
-#' data(iris_prtl, package="ggRandomForests")
+#' data(partial_iris, package="ggRandomForests")
 #' 
-#' ggrf_obj <- gg_partial(iris_prtl)
-#' plot(ggrf_obj)
+#' gg_dta <- gg_partial(partial_iris)
+#' plot(gg_dta)
 #' 
 #' ## ------------------------------------------------------------
 #' ## regression
 #' ## ------------------------------------------------------------
-#' 
+#' ## -------- air quality data
 #' ## airquality "Wind" partial dependence plot
 #' ##
-#' # airq_rf <- rfsrc(Ozone ~ ., data = airquality)
-#' # airq_prtl <- plot.variable(airq_rf, xvar.names = "Wind",
+#' # rfsrc_airq <- rfsrc(Ozone ~ ., data = airquality)
+#' # partial_airq <- plot.variable(rfsrc_airq, xvar.names = "Wind",
 #' #                            partial=TRUE, show.plot=FALSE)
-#' data(airq_prtl, package="ggRandomForests")
+#' data(partial_airq, package="ggRandomForests")
 #'
-#' ggrf_obj <- gg_partial(airq_prtl)
-#' plot(ggrf_obj)
+#' gg_dta <- gg_partial(partial_airq)
+#' plot(gg_dta)
+#' 
+#' gg_dta.m <- gg_dta[["Month"]]
+#' plot(gg_dta.m, notch=TRUE)
+#' 
+#' gg_dta[["Month"]] <- NULL
+#' plot(gg_dta, panel=TRUE)
+#' 
+#' ## -------- Boston data
+#' data(partial_Boston, package="ggRandomForests")
+#'
+#' gg_dta <- gg_partial(partial_Boston)
+#' plot(gg_dta)
+#' plot(gg_dta, panel=TRUE)
+#' 
+#' ## -------- mtcars data
+#' data(partial_mtcars, package="ggRandomForests")
+#'
+#' gg_dta <- gg_partial(partial_mtcars)
+#' 
+#' plot(gg_dta)
+#' 
+#' gg_dta.cat <- gg_dta
+#' gg_dta.cat[["disp"]] <- gg_dta.cat[["wt"]] <- gg_dta.cat[["hp"]] <- NULL
+#' gg_dta.cat[["drat"]] <- gg_dta.cat[["carb"]] <- gg_dta.cat[["qsec"]] <- NULL
+#'  
+#' plot(gg_dta.cat, panel=TRUE)
+#' 
+#' gg_dta[["cyl"]] <- gg_dta[["vs"]] <- gg_dta[["am"]] <- NULL
+#' gg_dta[["gear"]] <- NULL
+#' plot(gg_dta, panel=TRUE)
 #' 
 #' ## ------------------------------------------------------------
 #' ## survival examples
 #' ## ------------------------------------------------------------
+#' ## -------- veteran data
 #' ## survival "age" partial variable dependence plot
 #' ##
 #' # data(veteran, package = "randomForestSRC")
-#' # veteran_rf <- rfsrc(Surv(time,status)~., veteran, nsplit = 10, ntree = 100)
+#' # rfsrc_veteran <- rfsrc(Surv(time,status)~., veteran, nsplit = 10, ntree = 100)
 #' #
 #' ## 30 day partial plot for age
-#' # veteran_prtl <- plot.variable(veteran_rf, surv.type = "surv", 
+#' # partial_veteran <- plot.variable(rfsrc_veteran, surv.type = "surv", 
 #' #                               partial = TRUE, time=30, 
 #' #                               xvar.names = "age", 
 #' #                               show.plots=FALSE)
-#' data(veteran_prtl, package="ggRandomForests")
+#' data(partial_veteran, package="ggRandomForests")
 #' 
-#' ggrf_obj <- gg_partial(veteran_prtl)
-#' plot(ggrf_obj)
+#' gg_dta <- gg_partial(partial_veteran[[1]])
+#' plot(gg_dta)
+#' 
+#' gg_dta.cat <- gg_dta
+#' gg_dta[["celltype"]] <- gg_dta[["trt"]] <- gg_dta[["prior"]] <- NULL
+#' plot(gg_dta, panel=TRUE)
+#' 
+#' gg_dta.cat[["karno"]] <- gg_dta.cat[["diagtime"]] <- gg_dta.cat[["age"]] <- NULL 
+#' plot(gg_dta.cat, panel=TRUE, notch=TRUE)
+#' 
+#' gg_dta <- lapply(partial_veteran, gg_partial)
+#' length(gg_dta)
+#' gg_dta <- combine.gg_partial(gg_dta[[1]], gg_dta[[2]] )
+#' 
+#' plot(gg_dta[["karno"]])
+#' plot(gg_dta[["celltype"]])
+#' 
+#' gg_dta.cat <- gg_dta
+#' gg_dta[["celltype"]] <- gg_dta[["trt"]] <- gg_dta[["prior"]] <- NULL
+#' plot(gg_dta, panel=TRUE)
+#' 
+#' gg_dta.cat[["karno"]] <- gg_dta.cat[["diagtime"]] <- gg_dta.cat[["age"]] <- NULL 
+#' plot(gg_dta.cat, panel=TRUE, notch=TRUE)
+#' 
+#' ## -------- pbc data
 #' }
 #'
 #' @importFrom ggplot2 ggplot aes labs geom_point geom_smooth facet_wrap
@@ -132,11 +187,12 @@ plot.gg_partial_list <- function(x, points=TRUE, panel=FALSE, ...){
                        aes_string(x="value", y="yhat"))
       
     }else{
+      gg_dta$group  <- factor(gg_dta$group,levels=unique(gg_dta$group))
       gg_plt <- ggplot(gg_dta,
                        aes_string(x="value", y="yhat", color="group", shape="group"))
     }
     
-    if(sum(which(cls=="factor")==length(cls))){
+    if(sum(cls=="factor")==length(cls)){
       gg_plt <- gg_plt +
       geom_boxplot(...)
     }else{
@@ -144,9 +200,10 @@ plot.gg_partial_list <- function(x, points=TRUE, panel=FALSE, ...){
       geom_point(...)+
       geom_smooth(...)
     }
-    gg_plt <- gg_plt+
-    facet_wrap(~ variable,
-               scales="free_x")
+    return(gg_plt +
+           facet_wrap(~variable,
+                      scales="free_x")
+    )
   }else{
     # OR a list of figures.
     gg_plt <- vector("list", length=lng)
@@ -154,6 +211,7 @@ plot.gg_partial_list <- function(x, points=TRUE, panel=FALSE, ...){
     for(ind in 1:lng){
       gg_plt[[ind]] <- plot.gg_partial(gg_dta[[ind]], points, ...)
     }
-  }  
-  return(gg_plt)
+    
+    return(gg_plt)
+  }
 }
