@@ -13,19 +13,34 @@ test_that("gg_variable classifications",{
   expect_is(rfsrc_iris, "rfsrc")
   
   # Test the forest family
-  expect_that(rfsrc_iris$family, equals("class"))
+  expect_equal(rfsrc_iris$family, "class")
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_variable(rfsrc_iris)
+  gg_dta<- gg_variable(rfsrc_iris)
   
   # Test object type
-  expect_is(ggrf.obj, "gg_variable")
-#   
-#   ## Test plotting the gg_error object
-#   gg.obj <- plot.gg_variable(ggrf.obj, xvar = "Petal.Width", )
-#   
-#   # Test return is s ggplot object
-#   expect_is(gg.obj, "ggplot")
+  expect_is(gg_dta, "gg_variable")
+  
+  ## Test plotting the gg_error object
+  gg_plt <- plot.gg_variable(gg_dta, xvar = "Petal.Width", )
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
+  
+  ## Test plotting the gg_error object
+  gg_plt <- plot.gg_variable(gg_dta, xvar = rfsrc_iris$xvar.names )
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "list")
+  expect_equal(length(gg_plt), length(rfsrc_iris$xvar.names))
+  for(ind in 1:length(rfsrc_iris$xvar.names))
+    expect_is(gg_plt[[ind]], "ggplot")
+  ## Test plotting the gg_error object
+  gg_plt <- plot.gg_variable(gg_dta, xvar = rfsrc_iris$xvar.names,
+                             panel=TRUE)
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
 })
 
 
@@ -42,16 +57,36 @@ test_that("gg_variable survival",{
   expect_is(rfsrc_veteran, "rfsrc")
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_variable(rfsrc_veteran, time=30)
+  gg_dta<- gg_variable(rfsrc_veteran, time=30)
   
   # Test object type
-  expect_is(ggrf.obj, "gg_variable")
+  expect_is(gg_dta, "gg_variable")
   
   ## Test plotting the gg_variable object
-  gg.obj <- plot.gg_variable(ggrf.obj, xvar="age")
+  gg_plt <- plot.gg_variable(gg_dta, xvar="age")
   
   # Test return is s ggplot object
-  expect_is(gg.obj, "ggplot")
+  expect_is(gg_plt, "ggplot")
+  
+  
+  ## Test plotting the gg_variable object
+  gg_plt <- plot.gg_variable(gg_dta, xvar=rfsrc_veteran$xvar.names)
+  
+  # Test return is s ggplot object
+  expect_is(gg_plt, "list")
+  expect_equal(length(gg_plt), length(rfsrc_veteran$xvar.names))
+  
+  
+  for(ind in 1:length(rfsrc_veteran$xvar.names))
+    expect_is(gg_plt[[ind]], "ggplot")
+  
+  
+  ## Test plotting the gg_error object
+  expect_warning(gg_plt <- plot.gg_variable(gg_dta, xvar = rfsrc_veteran$xvar.names,
+                                            panel=TRUE)
+  )
+  # Test return is s ggplot object
+  expect_is(gg_plt, "ggplot")
 })
 
 test_that("gg_variable regression",{
@@ -67,14 +102,23 @@ test_that("gg_variable regression",{
   expect_is(rfsrc_airq, "rfsrc")
   
   ## Create the correct gg_error object
-  ggrf.obj<- gg_variable(rfsrc_airq)
+  gg_dta<- gg_variable(rfsrc_airq)
   
   # Test object type
-  expect_is(ggrf.obj, "gg_variable")
+  expect_is(gg_dta, "gg_variable")
   
   ## Test plotting the gg_error object
-  gg.obj <- plot.gg_variable(ggrf.obj)
+  gg_plt <- plot.gg_variable(gg_dta)
   
   # Test return is s ggplot object
-  expect_is(gg.obj[[1]], "ggplot")
+  expect_is(gg_plt, "list")
+  expect_equal(length(gg_plt), length(rfsrc_airq$xvar.names))
+  for(ind in 1:length(rfsrc_airq$xvar.names))
+    expect_is(gg_plt[[ind]], "ggplot")
+  
+  
+  ## Test plotting the gg_error object
+  gg_plt <- plot.gg_variable(gg_dta, panel=TRUE)
+  expect_is(gg_plt, "ggplot")
+  
 })
\ No newline at end of file
